/*
Copyright (c) 2007 Health Market Science, Inc.

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

You can contact Health Market Science at info@healthmarketscience.com
or at the following address:

Health Market Science
2700 Horizon Drive
Suite 200
King of Prussia, PA 19406
*/

package com.healthmarketscience.common.util;

import java.io.IOException;

/**
 * Should be implemented by an object which can append itself to an
 * AppendableExt object, where the work of generating a result for
 * {@code toString()} would itself involve the appending of multiple
 * CharSequences (Strings, etc).
 * <p>
 * In general, it is expected that the data appended to the AppendableExt an
 * {@link #appendTo} invocation be the same as the result of a call to
 * {@link Object#toString}.  If this is not the case, it should be clearly
 * documented in the class.
 * 
 * @author James Ahlborn
 */
public interface Appendee {

  /**
   * Appends this object to the given AppendableExt.  Called by an
   * AppendableExt when a request is made to append an instance of Appendee.
   *
   * @param a the AppendableExt to which this class should append itself
   * @throws IOException if the append fails
   */
  public void appendTo(AppendableExt a) throws IOException;
  
}
